@@ -52,7 +52,7 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
                 "Choose your Position Size for {} per trade in % (0.25 = 10% drawdown risk, 0.5 = 20% drawdown risk, 1.0 = 40% drawdown risk): ".format(symbol))
             pos_size = check_pos_size(pos_size)
             symbol_settings[symbol] = {
-                'position_size': pos_size, 'last_order_stop_id': '', 'last_order_stoploss_id': '', 'last_order_SL': '', 'last_order_qty': ''}
+                'position_size': pos_size, 'last_order_stop_id': '', 'last_order_stoploss_id': '', 'last_order_SL': '', 'last_order_qty': 0}
         return make_pickle_file(setting_name, token, api_key, api_secret, symbol_settings)
 
 
